@@ -90,6 +90,7 @@ sub xlat_objname {
 }
 
 sub main26 {
+   my (%summary_count, %summaries);
    open(fi, "find $linux | grep Kconfig\$ |") || die "find failed" ;
    Kconfig: foreach(<fi>) {
       my %dstrings;
@@ -105,14 +106,27 @@ sub main26 {
          }
       }
       while(<mk>) {
-         if(/obj-..(\w+).*=\s*(\w+)\.o/) {
-            if(defined($dstrings{$1})) {
-               print "summary_$2=\"$dstrings{$1}\"\n";
-            }
+         if(/obj-..(\w+).*=\s*((?:[\w-]+\.o\s*)+)$/) {
+	    my ($var, $files) = ($1, $2);
+	    warn "line=$_ var=$var files=$files" if $opt_d;
+	    my @files = ($files =~ /([\w-]+)\.o/g);
+	    warn "files=".join(":",@files)."\n" if $opt_d;
+	    foreach (@files) {
+	        s/-/_/g;
+                if(defined($dstrings{$var}) and !$summary_count{$_}++) {
+                   warn "summary_$_=\"$dstrings{$var}\"\n" if $opt_d;
+		   $summaries{$_} = $dstrings{$var};
+                   print "summary_$_=\"$dstrings{$var}\"\n";
+                }
+	    }
          }
       }
       close(kc);
       close(mk);
    }
+   warn "please check wether the following modules need a summary override\n";
+   while (my ($var, $count) = each %summary_count)  {
+       warn "multiple ($count) descriptions found for $var, used '$summaries{$var}'\n" if $count > 1;
+   }
    return 1;
 }
